@@ -22,7 +22,8 @@ LLDB_API SBAttachInfoRef CreateSBAttachInfo2(lldb_pid_t pid);
 
 LLDB_API SBAttachInfoRef CreateSBAttachInfo3(const char *path, bool wait_for);
 
-LLDB_API SBAttachInfoRef CreateSBAttachInfo4(const char *path, bool wait_for, bool async);
+LLDB_API SBAttachInfoRef CreateSBAttachInfo4(const char *path, bool wait_for,
+                                             bool async);
 
 LLDB_API SBAttachInfoRef CloneSBAttachInfo(SBAttachInfoRef instance);
 
@@ -30,17 +31,21 @@ LLDB_API void DisposeSBAttachInfo(SBAttachInfoRef instance);
 
 LLDB_API lldb_pid_t SBAttachInfoGetProcessID(SBAttachInfoRef instance);
 
-LLDB_API void SBAttachInfoSetProcessID(SBAttachInfoRef instance, lldb_pid_t pid);
+LLDB_API void SBAttachInfoSetProcessID(SBAttachInfoRef instance,
+                                       lldb_pid_t pid);
 
-LLDB_API void SBAttachInfoSetExecutable(SBAttachInfoRef instance, const char *path);
+LLDB_API void SBAttachInfoSetExecutable(SBAttachInfoRef instance,
+                                        const char *path);
 
-LLDB_API void SBAttachInfoSetExecutable2(SBAttachInfoRef instance, SBFileSpecRef exe_file);
+LLDB_API void SBAttachInfoSetExecutable2(SBAttachInfoRef instance,
+                                         SBFileSpecRef exe_file);
 
 LLDB_API bool SBAttachInfoGetWaitForLaunch(SBAttachInfoRef instance);
 
 LLDB_API void SBAttachInfoSetWaitForLaunch(SBAttachInfoRef instance, bool b);
 
-LLDB_API void SBAttachInfoSetWaitForLaunch2(SBAttachInfoRef instance, bool b, bool async);
+LLDB_API void SBAttachInfoSetWaitForLaunch2(SBAttachInfoRef instance, bool b,
+                                            bool async);
 
 LLDB_API bool SBAttachInfoGetIgnoreExisting(SBAttachInfoRef instance);
 
@@ -52,7 +57,8 @@ LLDB_API void SBAttachInfoSetResumeCount(SBAttachInfoRef instance, uint32_t c);
 
 LLDB_API const char *SBAttachInfoGetProcessPluginName(SBAttachInfoRef instance);
 
-LLDB_API void SBAttachInfoSetProcessPluginName(SBAttachInfoRef instance, const char *plugin_name);
+LLDB_API void SBAttachInfoSetProcessPluginName(SBAttachInfoRef instance,
+                                               const char *plugin_name);
 
 LLDB_API uint32_t SBAttachInfoGetUserID(SBAttachInfoRef instance);
 
@@ -74,19 +80,23 @@ LLDB_API bool SBAttachInfoEffectiveUserIDIsValid(SBAttachInfoRef instance);
 
 LLDB_API bool SBAttachInfoEffectiveGroupIDIsValid(SBAttachInfoRef instance);
 
-LLDB_API void SBAttachInfoSetEffectiveUserID(SBAttachInfoRef instance, uint32_t uid);
+LLDB_API void SBAttachInfoSetEffectiveUserID(SBAttachInfoRef instance,
+                                             uint32_t uid);
 
-LLDB_API void SBAttachInfoSetEffectiveGroupID(SBAttachInfoRef instance, uint32_t gid);
+LLDB_API void SBAttachInfoSetEffectiveGroupID(SBAttachInfoRef instance,
+                                              uint32_t gid);
 
 LLDB_API lldb_pid_t SBAttachInfoGetParentProcessID(SBAttachInfoRef instance);
 
-LLDB_API void SBAttachInfoSetParentProcessID(SBAttachInfoRef instance, lldb_pid_t pid);
+LLDB_API void SBAttachInfoSetParentProcessID(SBAttachInfoRef instance,
+                                             lldb_pid_t pid);
 
 LLDB_API bool SBAttachInfoParentProcessIDIsValid(SBAttachInfoRef instance);
 
 LLDB_API SBListenerRef SBAttachInfoGetListener(SBAttachInfoRef instance);
 
-LLDB_API void SBAttachInfoSetListener(SBAttachInfoRef instance, SBListenerRef listener);
+LLDB_API void SBAttachInfoSetListener(SBAttachInfoRef instance,
+                                      SBListenerRef listener);
 
 #ifdef __cplusplus
 }
