@@ -22,20 +22,25 @@ LLDB_API SBFileSpecListRef CloneSBFileSpecList(SBFileSpecListRef instance);
 
 LLDB_API void DisposeSBFileSpecList(SBFileSpecListRef instance);
 
-LLDB_API unsigned int SBFileSpecListGetSize(SBFileSpecListRef instance);
+LLDB_API uint32_t SBFileSpecListGetSize(SBFileSpecListRef instance);
 
-LLDB_API bool SBFileSpecListGetDescription(SBFileSpecListRef instance, SBStreamRef description);
+LLDB_API bool SBFileSpecListGetDescription(SBFileSpecListRef instance,
+                                           SBStreamRef description);
 
-LLDB_API void SBFileSpecListAppend(SBFileSpecListRef instance, SBFileSpecRef sb_file);
+LLDB_API void SBFileSpecListAppend(SBFileSpecListRef instance,
+                                   SBFileSpecRef sb_file);
 
-LLDB_API bool SBFileSpecListAppendIfUnique(SBFileSpecListRef instance, SBFileSpecRef sb_file);
+LLDB_API bool SBFileSpecListAppendIfUnique(SBFileSpecListRef instance,
+                                           SBFileSpecRef sb_file);
 
 LLDB_API void SBFileSpecListClear(SBFileSpecListRef instance);
 
-LLDB_API unsigned int SBFileSpecListFindFileIndex(SBFileSpecListRef instance, uint32_t idx,
-                                                      SBFileSpecRef sb_file, bool full);
+LLDB_API uint32_t SBFileSpecListFindFileIndex(SBFileSpecListRef instance,
+                                              uint32_t idx,
+                                              SBFileSpecRef sb_file, bool full);
 
-LLDB_API SBFileSpecRef SBFileSpecListGetFileSpecAtIndex(SBFileSpecListRef instance, uint32_t idx);
+LLDB_API SBFileSpecRef
+SBFileSpecListGetFileSpecAtIndex(SBFileSpecListRef instance, uint32_t idx);
 
 #ifdef __cplusplus
 }
